# OVOS plugin manager

OPM can be used to search, install, load and create plugins for the OpenVoiceOS ecosystem!

![logo](https://raw.githubusercontent.com/OpenVoiceOS/ovos_assets/921b41891ed18c9e16d24d1894266200ee3bd104/Logo/Raw/opm-logo.svg)

## Install

```bash
pip install ovos-plugin-manager
```

## Usage

see [./examples](examples) folder for basic usage


## Plugins

OPM provides templates to create OVOS plugins

#### List of plugins

This list is non exhaustive 

##### Wake Words
- [ovos-ww-plugin-hotkeys](https://github.com/OpenVoiceOS/ovos_ww_plugin_hotkeys)
- [ovos-ww-plugin-pocketsphinx](https://github.com/OpenVoiceOS/ovos-wakeword-plugin-pocketsphinx)
- [ovos-ww-plugin-precise](https://github.com/OpenVoiceOS/ovos-wake-word-plugin-precise)
- [chatterbox-ww-plugin-dummy](https://github.com/HelloChatterbox/dummy_wakeword_plugin)

##### TTS
- [ovos-tts-plugin-mimic](https://github.com/OpenVoiceOS/ovos-tts-plugin-mimic)
- [ovos-tts-plugin-mimic2](https://github.com/OpenVoiceOS/ovos-tts-plugin-mimic2)
- [ovos-tts-plugin-google](https://github.com/OpenVoiceOS/ovos-tts-plugin-google)
- [ovos-tts-plugin-responsivevoice](https://github.com/OpenVoiceOS/ovos-tts-plugin-responsivevoice)
- [ovos-tts-plugin-pico](https://github.com/OpenVoiceOS/ovos-tts-plugin-pico)
- [ovos-tts-plugin-espeakNG](https://github.com/OpenVoiceOS/ovos-tts-plugin-espeakNG)
- [chatterbox-polly-tts-plugin](https://github.com/HelloChatterbox/chatterbox-polly-tts-plugin)

##### STT
- [ovos-stt-plugin-vosk](https://github.com/OpenVoiceOS/ovos-stt-plugin-vosk)

##### Audio Service
- [ovos-guiplayer-plugin](https://github.com/OpenVoiceOS/ovos-guiplayer-plugin)
- [ovos-vlc-plugin](https://github.com/OpenVoiceOS/ovos-vlc-plugin)
